pub struct CodeiClient { /* private fields */ }Expand description
Programmatic entry point for running CodeI agents.
Implementations
Sourceimpl CodeiClient
impl CodeiClient
Sourcepub fn builder() -> CodeiClientBuilder
pub fn builder() -> CodeiClientBuilder
Examples found in repository?
9async fn main() -> Result<(), Box<dyn std::error::Error>> {
10 let prompt = std::env::args()
11 .nth(1)
12 .unwrap_or_else(|| "List all Rust source files in the current directory.".into());
13
14 let client = CodeiClient::builder().auto_approve(true).build().await?;
15
16 let result = client
17 .run_with_handler(&prompt, |event| match event {
18 codei_agent::AgentEvent::AssistantDelta { text } => print!("{text}"),
19 codei_agent::AgentEvent::ToolStarted { name, args } => {
20 eprintln!("\n[tool:{name}] {args}");
21 }
22 codei_agent::AgentEvent::ToolFinished { name, result } => {
23 eprintln!("[tool:{name}] {}", result.content);
24 }
25 _ => {}
26 })
27 .await?;
28
29 println!("\n\nsession={}", result.session_id);
30 Ok(())
31}Sourcepub async fn run_with_handler<F>(
&self,
prompt: &str,
on_event: F,
) -> Result<RunResult, SdkError>where
F: FnMut(AgentEvent),
pub async fn run_with_handler<F>(
&self,
prompt: &str,
on_event: F,
) -> Result<RunResult, SdkError>where
F: FnMut(AgentEvent),
Run a prompt and invoke on_event for each agent event.
Examples found in repository?
9async fn main() -> Result<(), Box<dyn std::error::Error>> {
10 let prompt = std::env::args()
11 .nth(1)
12 .unwrap_or_else(|| "List all Rust source files in the current directory.".into());
13
14 let client = CodeiClient::builder().auto_approve(true).build().await?;
15
16 let result = client
17 .run_with_handler(&prompt, |event| match event {
18 codei_agent::AgentEvent::AssistantDelta { text } => print!("{text}"),
19 codei_agent::AgentEvent::ToolStarted { name, args } => {
20 eprintln!("\n[tool:{name}] {args}");
21 }
22 codei_agent::AgentEvent::ToolFinished { name, result } => {
23 eprintln!("[tool:{name}] {}", result.content);
24 }
25 _ => {}
26 })
27 .await?;
28
29 println!("\n\nsession={}", result.session_id);
30 Ok(())
31}Auto Trait Implementations
impl !RefUnwindSafe for CodeiClient
impl !UnwindSafe for CodeiClient
impl Freeze for CodeiClient
impl Send for CodeiClient
impl Sync for CodeiClient
impl Unpin for CodeiClient
impl UnsafeUnpin for CodeiClient